#include "Map.h"
#include <fstream>
using namespace std;

void Map::Init() {
	for(int r = 0; r < MAPHEIGHT; r++) {
		for(int c = 0; c < MAPWIDTH; c++) {
			level[r][c] = 0;
		}
	}
}

void Map::loadMap(char *dir) {
	int whatIsA = (int)'A'; // to load back properly at all times
	char *filename = new char[40];
	sprintf(filename,"%s/map.dat",dir);
	ifstream TheFile(filename);
	if(!TheFile) {
		fprintf(stderr,"map file %s is missing\n",filename);
		TheFile.close();
		exit(1);
	}
	char line[MAPWIDTH+1]; // map width + 1
	for(int r = 0; r < MAPWIDTH; r++) {
		TheFile.getline(line,MAPWIDTH+2,'\n');
		for(int c = 0; c < MAPWIDTH; c++) {
			level[r][c] = (int)(line[c])-whatIsA;
			if(level[r][c] < 0) {
				fprintf(stderr,"negative tile at %i,%i\n",c,r);
				level[r][c] = 0;
			}
		}
	}
	delete[] filename;
	TheFile.close();
	printf("map loaded....\n");
}

void Map::saveMap(char *dir) {
	char *filename = new char[40];
	sprintf(filename,"%s/map.dat",dir);
	int whatIsA = (int)'A';
	ofstream TheFile(filename);
	for(int r = 0; r < MAPHEIGHT; r++) {
		for(int c = 0; c < MAPWIDTH; c++) {
			//printf("Writing %i\n",level[r][c] + whatIsA);
			TheFile << (char)(level[r][c] + whatIsA);
			//TheFile << "\n";
		}
		TheFile << "\n";
	}
	delete[] filename;
	printf("Written. closing\n");
	TheFile.close();
}

const bool Map::isSolid(float x, float y) {
	int tilex = (int)(x/48);
	int tiley = (int)(y/48);
	if(tiley + 1 >= MAPWIDTH || tilex + 1 >= MAPWIDTH || tilex < 0 || tiley < 0 || x < 0 || y < 0) {
		return 1;
	}
	int lvl = level[tiley][tilex];
	if(lvl == 1 || lvl == 2 || lvl == 4	|| lvl == 6 || lvl == 7 || lvl == 9
		|| lvl == 10 || lvl == 21 || lvl == 33 || lvl == 39 || lvl == 38 || lvl == 42
	    || lvl == 44 || lvl == 45 || lvl == 46) {
		return 1;
	}
	return 0;
}

int Map::getTileAt(int x, int y) {
	if(x >= 0 && x < MAPWIDTH && y >= 0 && y < MAPHEIGHT) {
		return level[y][x];
	}
	else {
		return 0;
	}
}

void Map::setTileAt(int x, int y, int value) {
	if(x >= 0 && x < MAPWIDTH && y >= 0 && y < MAPHEIGHT) {
		level[y][x] = value;
	}
}

const bool Map::isSea(float x, float y) {
	int tilex = (int)(x/48);
	int tiley = (int)(y/48);
	if(tiley + 1 >= MAPWIDTH || tilex + 1 >= MAPWIDTH || tilex < 0 || tiley < 0) {
		return 0;
	}
	if(level[tiley][tilex] == 21) {
		return 1;
	}
	return 0;
}

/*const bool Map::isUnbombable(int x, int y) {
	if(level[y][x] == 1) {
		return 1;
	}
	return 0;
}*/