#include <cstdio>
#include "player.h"
#include "defines.h"
#include <fstream>

/*
	actor-serializers.cpp
	Holds all the code for reading/writing an actor definition.
 
	Written intelligently for the best editing possible.
*/

int readNumberFromFile(std::ifstream &TheInputFile) {
	/*
		Reads the next line out of the file and returns it as a
		basic integer number
	*/
	char *line = new char[LINE_SIZE];
	TheInputFile.getline(line,LINE_SIZE,'\n');
	return atoi(line);
}

string readStringFromFile(std::ifstream &TheInputFile) {
	/*
		Reads the next line out of the file and returns it as a
		C++/STL string
	*/
	char *line = new char[LINE_SIZE];
	TheInputFile.getline(line,LINE_SIZE,'\n');
	string result = line;
	delete[] line;
	return result;
}

void writeStringToFile(string enter, std::ofstream &TheOutputFile) {
	/*
		Write the string into the file and then end with a newline
	*/
	TheOutputFile << enter.c_str();
	TheOutputFile << "\n";
}

void writeNumberToFile(int number, std::ofstream &TheOutputFile) {
	/*
		Write the number into the file and end with a newline
	*/
	TheOutputFile << number;
	TheOutputFile << "\n";
}

void Actor::serializeTo(char *filename) {
	/*
		Write an actor to disk
	*/
	std::ofstream TheOutputFile;
	TheOutputFile.open(filename);
	writeNumberToFile((int)x, TheOutputFile);
	writeNumberToFile((int)y , TheOutputFile );
	writeNumberToFile(stats.hp , TheOutputFile );
	writeNumberToFile(stats.hp_max , TheOutputFile );
	writeNumberToFile(stats.mp , TheOutputFile );
	writeNumberToFile(stats.mp_max , TheOutputFile );
	writeNumberToFile(stats.xp , TheOutputFile );
	writeNumberToFile(stats.level , TheOutputFile );
	writeNumberToFile(stats.strength , TheOutputFile );
	writeNumberToFile(stats.dexterity , TheOutputFile );
	writeNumberToFile(stats.intelligence , TheOutputFile );
	writeNumberToFile(flagId , TheOutputFile );
	if(bIsHostile) {
		writeNumberToFile(1 , TheOutputFile );
	} else {
		writeNumberToFile(0 , TheOutputFile );
	}
	writeStringToFile(conversation[0] , TheOutputFile );
	writeStringToFile(conversation[1] , TheOutputFile );
	writeStringToFile(myName , TheOutputFile );
	if(bIsWanderer) {
		writeNumberToFile(1 , TheOutputFile );
	} else {
		writeNumberToFile(0 , TheOutputFile );
	}
	writeNumberToFile(sprite , TheOutputFile );
	writeNumberToFile(direction , TheOutputFile );
	writeNumberToFile(stats.money, TheOutputFile);
	TheOutputFile.close();
}

int Actor::serializeFrom(char *filename) {
	/*
		Load an actor from disk
	*/
	std::ifstream TheInputFile;
	TheInputFile.open(filename);
	if(!TheInputFile) {
		fprintf(stderr,"***WARNING*** Input file %s missing on actor serialization load\nYou can probably ignore this.\n",filename);
		TheInputFile.close();
		return -1;
	}
	x = (float)readNumberFromFile(TheInputFile);
	y = (float)readNumberFromFile(TheInputFile);
	//printf("(x,y): %f %f\n",x,y);
	stats.hp = readNumberFromFile(TheInputFile);
	stats.hp_max = readNumberFromFile(TheInputFile);
	stats.mp = readNumberFromFile(TheInputFile);
	stats.mp_max = readNumberFromFile(TheInputFile);
	stats.xp = readNumberFromFile(TheInputFile);
	stats.level = readNumberFromFile(TheInputFile);
	stats.strength = readNumberFromFile(TheInputFile);
	stats.dexterity = readNumberFromFile(TheInputFile);
	stats.intelligence = readNumberFromFile(TheInputFile);
	flagId = readNumberFromFile(TheInputFile);
	if(readNumberFromFile(TheInputFile) > 0) {
		bIsHostile = true;
	} else {
		bIsHostile = false;
	}
	conversation[0] = readStringFromFile(TheInputFile);
	conversation[1] = readStringFromFile(TheInputFile);
	myName = readStringFromFile(TheInputFile);
	if(readNumberFromFile(TheInputFile) > 0) {
		bIsWanderer = true;
	} else {
		bIsWanderer = false;
	}
	sprite = readNumberFromFile(TheInputFile);
	direction = readNumberFromFile(TheInputFile);
	stats.money = readNumberFromFile(TheInputFile);
	TheInputFile.close();
	//TheOutputFile.close();
	return 0;
}