#include "vars.h"
#include "SDL_image.h"
#include <cstdlib>

void ArtAssets::loadAssets() {
	// Called from the game constructor, steps through until it finds the
	// hardcoded number of images in a convenient directory and shoves it into the game's waiting maw.
	char *filename = new char[50];
	SDL_Surface *temp;
	for(int c = 0; c < MAX_CHARS; c++) {
		for(int d = 0; d < 4; d++) {
			for(int f = 0; f < 3; f++) {
				sprintf(filename,"data/assets/sprites/%i/%i-%i.png",c,d,f);
				sprites[c][d][f] = IMG_Load(filename);
				if(!sprites[c][d][f]) {
					fprintf(stderr,"***CRITICAL ERROR*** Sprite %s not found...\n",filename);
					exit(1);
				}
				temp = SDL_DisplayFormatAlpha(sprites[c][d][f]);
				SDL_FreeSurface(sprites[c][d][f]);
				sprites[c][d][f] = temp;
			}
		}
	}
	bool bDoneItems = false;
	int i = 0;
	while(!bDoneItems) {
		sprintf(filename,"data/assets/items/%i.png",i);
		SDL_Surface *loaded = IMG_Load(filename);
		if(!loaded) {
			fprintf(stderr,"Warning: %s doesn't exist (can be ignored)\n",filename);
			bDoneItems = true; // Done loading
			break;
		}
		temp = SDL_DisplayFormatAlpha(loaded);
		SDL_FreeSurface(loaded);
		loaded = temp;
		items.push_back(loaded);
		i++;
	}
	for(int z = 0; z < MAX_ICONS; z++) {
		sprintf(filename,"data/assets/icns/%i.png",z);
		icons[z] = IMG_Load(filename);
		if(!icons[z]) {
			fprintf(stderr,"%s doesn't exist\n",filename);
			exit(1);
		}
		temp = SDL_DisplayFormatAlpha(icons[z]);
		SDL_FreeSurface(icons[z]);
		icons[z] = temp;
	}
	bool bDoneTiles = false;
	int t = 0;
	while(!bDoneTiles) {
		sprintf(filename,"data/assets/tiles/%i.png",t);
		SDL_Surface *loaded = IMG_Load(filename);
		if(!loaded) {
			fprintf(stderr,"%s doesn't exist\n",filename);
			bDoneTiles = true;
			break;
		}
		temp = SDL_DisplayFormatAlpha(loaded); // Should convert as well??
		SDL_FreeSurface(loaded);
		tiles.push_back(temp);
		t++;
	}
	printf("Assets loaded.\n");
	delete[] filename;
}

void ArtAssets::unloadAssets() {
	// Okay, time to die
	int assets = 0;
	for(unsigned int c = 0; c < MAX_CHARS; c++) {
		for(unsigned int d = 0; d < 4; d++) {
			for(unsigned int f = 0; f < 3; f++) {
				SDL_FreeSurface(sprites[c][d][f]);
				assets++;
			}
		}
	}
	for(unsigned int t = 0; t < tiles.size(); t++) {
		SDL_FreeSurface(tiles[t]);
		assets++;
	}
	for(unsigned int z = 0; z < MAX_ICONS; z++) {
		SDL_FreeSurface(icons[z]);
		assets++;
	}
	for(unsigned int i = 0; i < items.size(); i++) {
		SDL_FreeSurface(items[i]);
		assets++;
	}
	printf("%i art assets unloaded\n",assets);
}


ArtAssets::ArtAssets() {
	// Set all imaginable pointers to NULL. This will probably help me later on,
	// since we won't be referencing memory that doesn't exist.
	for(int c = 0; c < MAX_CHARS; c++) {
		for(int d = 0; d < 4; d++) {
			for(int f = 0; f < 3; f++) {
				sprites[c][d][f] = NULL;
			}
		}
	}
	/*for(int t = 0; t < tiles.size(); t++) {
		tiles[t] = NULL;
	}*/
	for(int z = 0; z < MAX_ICONS; z++) {
		icons[z] = NULL;
	}
	/*for(int i = 0; i < MAX_ITEMS; i++) {
		items[i] = NULL;
	}*/
}