#ifndef _CSRPG2_H_
#define _CSRPG2_H_

#include <list>
#include <vector>

#include "SDL_ttf.h"

#include "player.h"
#include "item.h"
#include "quest.h"
#include "defines.h"
#include "vars.h"
#include "fightvars.h"

using namespace std;

class CGame {
	/*
		This is it... all the data for the game is contained in this massive, virtually uncontrollable class
	*/
private:
	//// --------- FUNCTIONALITY ---------
	void drawMap();							//// Draw the map relative to the character
	void getInput();						//// Read keyboard input, make smart decisions
	void drawSprites();						//// Iterate through the loop, draw rel to camera
	void drawHud();							//// draw UI icons
	void inventoryMenu();					//// the loop for your inventory
	void playerInfoScreen();				//// displays completion status
	string getNextQuest();					//// all functionality for quest system
	void AIManager();						//// wandering, hostile AI
	void fightAI(Actor *actor, Actor *target); //// calculate actor's attack on player
	int fightAIMove(Actor *actor,
					 Actor *target);		//// calculate actor movement
	void keyHelp();							//// display key help
	void shopLoop(int type);				//// the magical shop!
	void gambleLoop();						//// Need quick cash? Visit the Ravcino!
	//// --------- ASSETS ----------------
	ArtAssets art;							//// All the game's art files
	AudioAssets audio;						//// All the game's audio files
	//// --------- ENTITY MANAGEMENT -----
	list <Actor*> actorList;
	void loadActors(char *dir);							//// Master serialization control
	void saveActors(char *dir);
	vector <Item*> itemVec;
	void loadItems(char *dir);
	void saveItems(char *dir);
	list <Quest*> questList;
	void loadQuests(char *dir);
	void saveQuests(char *dir);
	//// --------- LOOPS -----------------
	void menuLoop();						//// draws the game menus to screen, starting with inventory
	void gameLoop();						//// the heart of the game.
	string inputLoop();						//// lets player type in the name of a custom game to load
public:
	//// --------- UTILITY METHODS -------
	CGame();								//// activates all of the various initialization functions
	~CGame();
	void begin();							//// kicks game engine into gear
	int loadGame(char *dir);			//// loads a saved game from disk
	void loadAndStart(char *dir);
	void beginNewGame();					//// begins a new game
	void saveGame(char *dir);			//// saves a game to disk
	Item *returnItem(string shortName);		//// returns a ptr to the requested item from shortname
	Quest *returnQuest();					//// returns the next good (NOT DONE) quest, keeps complexity out of
											//// player classes
	void wipeEntities();
	void drawTextAt(const char *text, int x, int y);
	void drawAlphaTextAt(const char *text, int x, int y, int alpha);
	void centreTextAt(const char *text, int y);
	void centreAlphaTextAt(const char *text, int y, int alpha);
	int returnTextHeight();
	float distance(float ax, float ay, float bx, float by);
	bool spriteCollision(float ax, float ay, float aw, float ah, float bx, float by, float bw, float bh);
	void startTalking();
	void rebuildShopVector(vector <Item*> &shopVec, vector <Item*> itemVec, int owner, int type);
	void findSleep();
	void pickupObjects();					//// grab objects near the player, reallocate them
											//// self explanatory
	void drawFightHUD();
	void drawFightConsole();
	void getFightInput();
	void buildWeaponVector(vector <Item*> &vec);	//// build an item vector containing only weapons
	//// --------- STATE VARIABLES -------
	bool bPlayingGame;						//// tells the game engine not to draw menus
	int mode;								//// if you are not playing the game, you are in another mode
											////	inventory screen called from inside game loop.
											////	this should probably be set to = 1 for "fight loop"
	bool bMustQuit;							//// tells the game engine to quit at next opportunity
	bool bPleaseLoadGame;					//// tells the wrapper to ice the program
	//// --------- MISCELLANEOUS VARS ----
	MiscVars vars;							//// contains our miscellaneous variables and keeps them out of our
											//// class definition
	FightVars fvars;						//// variables for fighting
	SDL_Surface *screen;					//// screen surface. MUST BE GLOBAL
	TTF_Font *font;							//// game's font.
	SDL_Event event;						//// the input interface.
	Map *theMap;							//// the level geometry
	Actor *player;							//// the game's player.
	Actor *enemy;							//// the character the player is fighting at the moment.
	Actor *findPlayerActor();				//// returns the first active player actor from the linked list
	bool playerNPCcollision(float x, float y); //// checks for a collision between the player and any npc
	bool NPCcollision(float x, float y, Actor *oa);
	bool mapCollision(float tx, float ty);
	bool combatCollide(Actor *a1, Actor *a2, int dx, int dy);
	void unequipAllItems(vector <Item*> vec);	//// for use before equipping armour
	int textHeight;							//// cached
	void drawFightEffects();
	void deathScreen();						//// when you die..
	void fightEffectAt(float x, float y, int icon, char *txt);
	void effectAlongLine(float wx1, float wy1, float wx2, float wy2, int icon);
											//// Do the smarts to position it onscreen
	void fightPanel();						//// Raise the "battle on!" screen in a loop
	void updateBullet();					//// update "bullets" for fight effects.
	void pollScreenshot();					//// don't delete this; it's actually used O_o
	void cleanUpFightVars();
	int unlockDoor(float x, float y, bool bPick, bool bMotel);		//// Guess.
	void ScrollyText(char *str);			//// Once again, guess what this does.
	char *gamblingMadLibs();				//// Generates a string containing the crap you're gambling on
	void playSound(int num);				//// Plays a noise
	void loadAndShowEnding(string dir);		//// Show an ending from the data dir.
	void calculateEndings();				//// Find out if the player is ready to finish.
	void raiseError(char *str);				//// Allows you to raise an error in OS-specific ways
	void errorDialogue(char *str);			//// Error dialogue box
	float TALK_TIMER;						//// a constant for how long you want the talk to work
	int SCREEN_WIDTH;						//// a const for widescreen mode
	SDL_Joystick *joystick;
};

#endif