#include "csrpg2.h"
#include <fstream>
#include "SDL_image.h"
using namespace std;

#define MAX_ENDING 20
#define PHOTO_WHIP_SPEED 400

void CGame::loadAndShowEnding(string dir) {
	/*
		Display an ending similar to a "holiday slideshow".
		Maybe kick off some funky music here.
	*/
	vector <SDL_Surface*> slides;
	// First, load all the pngs in the endings directory.
	int i = 0;
	bool bDone = false;
	char *fname = new char[80];
	while(!bDone) {
		// Load each png in turn
		sprintf(fname,"%s/ending/%i.png",dir.c_str(),i);
		SDL_Surface *temp = IMG_Load(fname);
		if(temp) {
			// Drop it into our slides vector
			slides.push_back(temp);
		} else {
			bDone = true;
		}
		i++;
	}
	delete[] fname;
	if(slides.size() < 1) {
		return; // give up
	}
	// Then, oscillate through them with the slideshow manager.
	bool bDoneShow = false;
	bool bAdvancingSlide = false;
	bool bFallingSlide = false;
	bool bWeAreDone = false;
	Uint32 z = 0;
	float photo_x = (SCREEN_WIDTH - slides[z]->w)/2;
	float photo_y = (600 - slides[z]->h)/2;
	while(!bDoneShow) {
		// Iterate through the photos one at a time.
		vars.timer_start = SDL_GetTicks();
		// Clear the screen
		SDL_FillRect(screen,NULL,SDL_MapRGB(screen->format,GUI_COLOR_RED,GUI_COLOR_GREEN,GUI_COLOR_BLUE));
		// Draw the slide.
		SDL_Rect rect;
		rect.x = (Sint16)photo_x;
		rect.y = (Sint16)photo_y;
		if(z < slides.size()) {
			SDL_BlitSurface(slides[z],NULL,screen,&rect);
		} else {
			bWeAreDone = true;
		}
		if(bAdvancingSlide) {
			// If we're advancing the slide, move it to the right until we fall off.
			// Then grab the next slide.
			photo_x += PHOTO_WHIP_SPEED*vars.timer_delta;
			if(photo_x > SCREEN_WIDTH) {
				bAdvancingSlide = false;
				z++;
				if(z < slides.size()) {
					// Reposition the new photo, then toss it in
					photo_x = SCREEN_WIDTH;
					photo_y = (600 - slides[z]->h)/2;
					bFallingSlide = true;
				} else {
					// We're out of slides and must finish
					bWeAreDone = true;
				}
			}
		}
		if(bFallingSlide) {
			// We're bringing the slide back in.
			photo_x -= PHOTO_WHIP_SPEED*vars.timer_delta;
			if(photo_x <= ((SCREEN_WIDTH - slides[z]->w)/2)) {
				photo_x = ((SCREEN_WIDTH - slides[z]->w)/2);
				bFallingSlide = false;
			}
		}
		while(SDL_PollEvent(&event)) {
			// Poll for input to see if we should advance or die.
			if(event.type == SDL_QUIT) {
				bDoneShow = true;
			}
			else if(event.type == SDL_KEYDOWN && !bFallingSlide && !bAdvancingSlide) {
				if(event.key.keysym.sym == SDLK_ESCAPE) {
					bDoneShow = true;
				}
				else {
					if(!bWeAreDone) {
						bAdvancingSlide = true;
					} else {
						bDoneShow = true;
					}
				}
			}
		}
		if(bWeAreDone) {
			drawTextAt("Thank you for playing!!!",0,0);
			drawTextAt("Please press any key to return to game.",0,returnTextHeight());
		}
		drawTextAt("Any key to advance slide, ESC to quit",0,600-returnTextHeight());
		SDL_Flip(screen);
		SDL_Delay(0);
		vars.timer_elapsed = SDL_GetTicks() - vars.timer_start;
		vars.timer_delta = vars.timer_elapsed / 1000.0f;
	}
	// TODO: Some cleanup here, make it delete the surfaces now that it's done with them.
	bMustQuit = true;
	bPleaseLoadGame = true;
	for(unsigned int i = 0; i < slides.size(); i++) {
		SDL_FreeSurface(slides[i]);
	}
}

void CGame::calculateEndings() {
	list <Quest*>::iterator qit;
	for(qit = questList.begin(); qit != questList.end(); qit++) {
		Quest *tq = *qit;
		if(!tq->bIsCompleted) {
			// Our player is a filthy liar and has not finished the game.
			vars.talkTimer = TALK_TIMER;
			vars.currentTalk = "You aren't done yet. Finish your quests, adventurer!";
			return;
		}
	}
	printf("Showing ending at %s\n",vars.dir.c_str());
	loadAndShowEnding(vars.dir);
}