#ifndef _PLAYER_H_
#define _PLAYER_H_

#include "SDL.h"
#include <string>
#include "Map.h"
using namespace std;

/*
	Actor:
	The class that contains every moving, walking, talking character, PC, NPC or not.
*/

struct CharacterStats {
	int hp;
	int hp_max;
	int mp;
	int mp_max;
	
	unsigned int xp;						/// Experience points for the player
	unsigned int level;					/// The character's current level of combat experience
	unsigned int strength;				/// The "strength" stat -- lets you hit harder and take less damage
	unsigned int dexterity;				/// Dexterity -- Lets you dodge & move faster
	unsigned int intelligence;			/// Intelligence -- lets you cause more damage with spells
	
	unsigned int money;					/// how much gold do you have?
};

class Actor {
	public:
	float x, y;					/// (x,y) locations (GAMEWORLD ONLY)
	CharacterStats stats;
	
	int flagId;					/// the conversation flag that this NPC will change on
	bool bIsHostile;			/// is this an enemy?
	string conversation[2];		/// the first one is the unflagged, the second one flagged
	string myName;				/// character's name
	bool bIsWanderer;			/// Does the character wander around?
	
	// Art Info
	int sprite;					/// what sprite is this?
	int direction;				/// what direction is this?
	int walkFrame;				/// if > 0 the sprite is moving. [NOT SAVED]
	float frameTimer;			/// ticks between frames.		[NOT SAVED]
	
	// Optimization info
	bool bIsActive;				/// when the player moves out of range of this character they go inactive
	
	// Save/load from file
	void serializeTo(char *filename);				/// Saves the current character to a UDEF file
	int serializeFrom(char *filename);				/// Loads the current character from a UDEF file
	void debugInfo();								/// Prints out current stats to console
	void animate(float delta);						/// Animate the character.
	bool canSee(float px, float py, Map* theMap);   /// Determines if the NPC can 'see' the player; if so attack
	bool bIsEnraged;								/// Is this NPC currently seeing you?
	int wdir;										/// What is their current wandering dir?
	float wtimer;									/// how long has it been since they last changed direction?
	
	Actor();
};
/*
class Player : public Actor {
	Player();
};*/

#endif
