#ifndef _VARS_H_
#define _VARS_H_

#include <string>
#include <vector>
#include "defines.h"
#include "SDL.h"
#include "SDL_mixer.h"
using namespace std;

class MiscVars {
	/*
		Holds all miscellaneous/state variables for the game engine, to reduce clutter
	*/
	public:
	int menuScreen;			/// what menu screen are you on right now? inventory? controls? options?
	float timer_start;		/// the start of the frame
	float timer_elapsed;	/// how much time it took to draw the last frame
	float timer_delta;		/// time compression factor based on elapsed timer
	Uint32 frames;			/// number of frames drawn by game engine
	float drunkenness;		/// when you drink beer... you get drunk
	string gameName;		/// what is the name of the currently loaded module?
	MiscVars();				/// initialize the default values for all miscellaneous variables
	bool flags[MAX_FLAGS];  /// the flags for plot advancement
	float talkTimer;		/// how much time is left
	float drunktimer;		/// if you're really smashed this will screw up your control.
	string currentTalk;		/// completed string for talking
	int fps;				/// frames per second
	void serializeTo(char *filename);
	int serializeFrom(char *filename);
	std::vector <string> fightMsgVec; /// fight console messages. cleared each battle
	bool bYourTurn;
	bool bFastWater;		/// Game setting. Don't draw water tiles, and rely on the "background" to do it for us.
	int fps_max;			/// top fps this game
	int fps_min;			/// worst fps this game
	bool bNoAlpha;			/// disable "Alpha-ized" dialogue
	bool debugMode;			/// draw debug info?
	bool bCheatPick;		/// lockpicks never break
	bool hasFloater;		/// do they have the devices to let them walk on water?!
	string dir;				/// what directory did I come from?
};

class ArtAssets {
	/*
		Holds all variables containing art data, to reduce clutter
	*/
	public:
	SDL_Surface *sprites[MAX_CHARS][4][3];				// Character sprite data, with pose
	//SDL_Surface *items[MAX_ITEMS];
	vector <SDL_Surface*> items;
	SDL_Surface *icons[MAX_ICONS];					// Icons for fighting, menu, etc.
	//SDL_Surface *tiles[MAX_TILES];
	vector <SDL_Surface*> tiles;
	void loadAssets();
	void unloadAssets();
	ArtAssets();
};

class AudioAssets {
	/*
		Holds all variables containing audio data, to reduce clutter
	*/
	public:
	AudioAssets();
	bool bSoundOff;
	Mix_Chunk *sfx[MAX_SOUNDS];
};

#endif