#include "editor.h"

void MapEditor::getInput() {
	while(SDL_PollEvent(&event)) {
		if(event.type == SDL_QUIT) {
			exit(1);
		}
		else if(event.type == SDL_MOUSEBUTTONDOWN) {
			if(event.button.button == 1) {
				// "Single Install" mode
				if(bMiniMap && event.button.x < (our_minimap->w-(800/48)) && event.button.y < (our_minimap->h-(600/48))) {
					// Jump around on the map
					x = event.button.x;
					y = event.button.y;
					printf("jump to -> %i,%i\n",x,y);
					/*if(y > (our_minimap->h/48)-(600/48)) {
						y = (our_minimap->h/48) - (600/48);
					}
					if(x > (our_minimap->w/48)-(800/48)) {
						x = (our_minimap->w/48) - (800/48);
					}*/
				}
				else if(bPalette && event.button.x < 48) {
					// Pick a tile from the palette
					curTile = (event.button.y/48)+scroll;
				} else {
					// Lay a tile
					//theMap.level[(event.button.y/48)+y][(event.button.x/48)+x] = curTile;
					int tx = (event.button.x/48)+x;
					int ty = (event.button.y/48)+y;
					theMap.setTileAt(tx,ty,curTile);
					printf("%i,%i\n",tx,ty);
					reloadMinimap();
				}
			}
			else {
				if(mode == SELECT_MODE) {
					// "Area Select" mode
					if(x1 != -1) {
						x2 = (event.button.x / 48) + x;
						y2 = (event.button.y / 48) + y;
						int temp = 0;
						if(x2 < x1) {
							temp = x1;
							x1 = x2;
							x2 = temp;
						}
						if(y2 < y1) {
							temp = y1;
							y1 = y2;
							y2 = temp;
						}
					}
					else {
						x1 = (event.button.x / 48) + x;
						y1 = (event.button.y / 48) + y;
					}
				}
				else if(mode == NPC_PLACE_MODE) {
					// Determine the x and y locs to place him in world coords
					int place_x = (event.button.x) + (x*48);
					int place_y = (event.button.y) + (y*48);
					createNewNPCAt(place_x,place_y);
				}
				else if(mode == ITEM_PLACE_MODE) {
					int place_x = (event.button.x) + (x*48);
					int place_y = (event.button.y) + (y*48);
					createNewItemAt(place_x,place_y);
				}
				else if(mode == ITEM_KILL_MODE) {
					int place_x = (event.button.x) + (x*48);
					int place_y = (event.button.y) + (y*48);
					killItemAt(place_x,place_y);
				}
				else if(mode == NPC_KILL_MODE) {
					int place_x = (event.button.x) + (x*48);
					int place_y = (event.button.y) + (y*48);
					killNPCAt(place_x,place_y);
				}
			}
		}
	}
	Uint8 *keystate = SDL_GetKeyState(NULL);
	if(keystate[SDLK_UP]) {
		y--;
		if(y < 0) {
			y = 0;
		}
		SDL_Delay(100);
	}
	else if(keystate[SDLK_DOWN]) {
		y++;
		SDL_Delay(100);
	}
	if(keystate[SDLK_LEFT]) {
		x--;
		if(x < 0) {
			x = 0;
		}
		SDL_Delay(100);
	}
	else if(keystate[SDLK_RIGHT]) {
		x++;
		SDL_Delay(100);
	}
	if(keystate[SDLK_LEFTBRACKET]) {
		curTile--;
		if(curTile < 0) {
			curTile = MAX_TILES - 1;
		}
		SDL_Delay(100);
	}
	else if(keystate[SDLK_RIGHTBRACKET]) {
		curTile++;
		if(curTile >= MAX_TILES) {
			curTile = 0;
		}
		SDL_Delay(100);
	}
	if(keystate[SDLK_q]) {
		if(scroll > 0) {
			scroll--;
		}
		SDL_Delay(25);
	}
	else if(keystate[SDLK_a]) {
		if(scroll < (MAX_TILES-1)) {
			scroll++;
		}
		SDL_Delay(25);
	}
	if(keystate[SDLK_p]) {
		bPalette = !bPalette;
		SDL_Delay(100);
	}
	if(keystate[SDLK_m]) {
		bMiniMap = !bMiniMap;
		SDL_Delay(200);
	}
	if(keystate[SDLK_s]) {
		theMap.saveMap("data_modified");
		saveActors("data_modified");
		saveItems("data_modified");
		drawTextAt("Saved into data_modified, did not overwrite existing files.",0,0);
		SDL_Delay(200);
	}
	else if(keystate[SDLK_l]) {
		if(!bJustLoaded) {
			theMap.loadMap("data");
			loadActors("data");
			loadItems("data");
			reloadMinimap();
			bJustLoaded = true;
		}
		SDL_Delay(200);
	}
	else if(keystate[SDLK_z]) {
		// Advance right click mode
		mode++;
		if(mode > 4) {
			mode = 0;
		}
		SDL_Delay(100);
	}
	if(keystate[SDLK_ESCAPE]) {
		exit(1);
	}
	if(keystate[SDLK_f]) {
		if(x1 != -1) {
			for(int i = x1; i <= x2; i++) {
				for(int j = y1; j <= y2; j++) {
					//theMap.level[j][i] = curTile;
					theMap.setTileAt(i,j,curTile);
				}
			}
		}
		x1 = -1;
		x2 = -1;
		y1 = -1;
		y2 = -1;
		reloadMinimap();
	}
	else if(keystate[SDLK_F3]) {
		SDL_SaveBMP(screen,"sshot.bmp");
		SDL_Delay(100);
	}
}
