#include "editor.h"
#include "Map.h"
#include "SDL.h"

SDL_Surface* MapEditor::renderMinimap(Map &theMap) {
	/*
		Takes: A loaded map
		Returns: A new SDL surface, in pixels wide by tall of the map size
	*/
	int width = MAPWIDTH;
	int height = MAPHEIGHT;
	// Spawn the new surface
	SDL_Surface *minimap = SDL_CreateRGBSurface(0,width,height,16,0,0,0,0);
	if(!minimap) {
		return NULL;
	}
	for(int x = 0; x < width; x++) {
		for(int y = 0; y < height; y++) {
			SDL_Rect rect;
			rect.x = x;
			rect.y = y;
			rect.w = 1;
			rect.h = 1;
			if(theMap.isSolid(x*48,y*48) && !theMap.isSea(x*48,y*48)) {
				SDL_FillRect(minimap,&rect,SDL_MapRGB(screen->format,0,0,0));
			}
			else if(theMap.isSea(x*48,y*48)) {
				SDL_FillRect(minimap,&rect,SDL_MapRGB(screen->format,0,0,255));
			}
			else {
				SDL_FillRect(minimap,&rect,SDL_MapRGB(screen->format,100,100,100));
			}
		}
	}
	//SDL_SetColorKey(minimap, SDL_SRCCOLORKEY|SDL_RLEACCEL, SDL_MapRGB(minimap->format,100,100,100));
	SDL_SetAlpha(minimap, SDL_SRCALPHA, 100);
	return SDL_DisplayFormat(minimap);
}

void MapEditor::drawScrollbox(int sx, int sy) {
	if(bMiniMap) {
		SDL_Rect rect;
		rect.x = sx;
		rect.y = sy;
		rect.w = (800/48)+1;
		rect.h = 1;
		//rect.h = (600/48)+1;
		// Draw top
		SDL_FillRect(screen,&rect,SDL_MapRGB(screen->format,100,0,0));
		rect.y = sy + (600/48)+1;
		// Draw base
		SDL_FillRect(screen,&rect,SDL_MapRGB(screen->format,100,0,0));
		rect.w = 1;
		rect.y = sy;
		rect.h = (600/48)+1;
		// Draw left
		SDL_FillRect(screen,&rect,SDL_MapRGB(screen->format,100,0,0));
		rect.x = sx + (800/48)+1;
		// Draw right
		SDL_FillRect(screen,&rect,SDL_MapRGB(screen->format,100,0,0));
	}
}

void MapEditor::reloadMinimap() {
	SDL_FreeSurface(our_minimap);
	our_minimap = renderMinimap(theMap);
}